Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2012-12-23 15:31:15 +0400
committerBastien Montagne <montagne29@wanadoo.fr>2012-12-23 15:31:15 +0400
commitba14beb000fef2c5911b4e17c0bf260de1cf251d (patch)
tree1fe8bbf7d8ebe9b16672cf856067543c684d010c /source/gameengine/Converter
parentc4a165f168196b52ed66105bbe99fe51da8b5317 (diff)
Code cleanup: add usual 'BKE_' prefix to 'public' constraint functions from blenkernel...
Diffstat (limited to 'source/gameengine/Converter')
-rw-r--r--source/gameengine/Converter/BL_ArmatureObject.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/source/gameengine/Converter/BL_ArmatureObject.cpp b/source/gameengine/Converter/BL_ArmatureObject.cpp
index 1f1c404efcb..395a57d753c 100644
--- a/source/gameengine/Converter/BL_ArmatureObject.cpp
+++ b/source/gameengine/Converter/BL_ArmatureObject.cpp
@@ -112,7 +112,8 @@ void game_copy_pose(bPose **dst, bPose *src, int copy_constraint)
if (copy_constraint) {
ListBase listb;
// copy all constraint for backward compatibility
- copy_constraints(&listb, &pchan->constraints, FALSE); // copy_constraints NULLs listb, no need to make extern for this operation.
+ // BKE_copy_constraints NULLs listb, no need to make extern for this operation.
+ BKE_copy_constraints(&listb, &pchan->constraints, FALSE);
pchan->constraints= listb;
} else {
pchan->constraints.first = NULL;
@@ -304,7 +305,7 @@ void BL_ArmatureObject::LoadConstraints(KX_BlenderSceneConverter* converter)
case CONSTRAINT_TYPE_TRANSFORM:
case CONSTRAINT_TYPE_DISTLIMIT:
case CONSTRAINT_TYPE_TRANSLIKE:
- cti = constraint_get_typeinfo(pcon);
+ cti = BKE_constraint_get_typeinfo(pcon);
gametarget = gamesubtarget = NULL;
if (cti && cti->get_constraint_targets) {
ListBase listb = { NULL, NULL };